"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var projectPath = global.rootPath || process.cwd();
var resolveFileName = require("./resolveFileName");
var logMap = null;
function disposeLogMap(arr) {
    logMap = {};
    for (var _i = 0, arr_1 = arr; _i < arr_1.length; _i++) {
        var item = arr_1[_i];
        var propArr = item.split('.');
        logMap[propArr[0]] = logMap[propArr[0]] || {};
        logMap[propArr[0]][propArr[1]] = true;
    }
    return logMap;
}
module.exports = function () {
    return {
        visitor: {
            CallExpression: function (nodePath, state) {
                var _a;
                logMap =
                    logMap ||
                        disposeLogMap(state.opts.logger || ['logger.log', 'logger.info', 'logger.wran', 'logger.error', 'logger.debug']);
                var callee = nodePath.node.callee;
                if (callee.object && ((_a = logMap[callee.object.name]) === null || _a === void 0 ? void 0 : _a[callee.property.name])) {
                    var filename = state.file.opts.filename;
                    var params = {
                        filename: filename,
                        projectPath: projectPath,
                        prefix: state.opts.prefix || '',
                        line: nodePath.node.loc.start.line,
                        column: nodePath.node.loc.start.column,
                    };
                    var value = '';
                    switch (typeof state.opts.resolveFileName) {
                        case 'function':
                            value = state.opts.resolveFileName(params);
                            break;
                        case 'string':
                            if (resolveFileName[state.opts.resolveFileName]) {
                                value = resolveFileName[state.opts.resolveFileName](params);
                                break;
                            }
                        default:
                            value = resolveFileName['acronyms'](params);
                    }
                    if (nodePath.node.arguments[0].value !== value) {
                        nodePath.node.arguments.unshift({
                            type: 'StringLiteral',
                            value: value,
                        });
                    }
                }
            },
        },
    };
};
